summaryrefslogtreecommitdiffstats
path: root/chrome/common/gpu_video_common.h
diff options
context:
space:
mode:
authorhclam@chromium.org <hclam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-03 18:57:24 +0000
committerhclam@chromium.org <hclam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-09-03 18:57:24 +0000
commit1cfb7420fb7ea2fa5a6360bbee5424918e84a027 (patch)
tree6ca1fd441d8675a06370fc54ac06bcbeb099b5fa /chrome/common/gpu_video_common.h
parent6b723128f5c6b090b87949875dcc4e55304a4461 (diff)
downloadchromium_src-1cfb7420fb7ea2fa5a6360bbee5424918e84a027.zip
chromium_src-1cfb7420fb7ea2fa5a6360bbee5424918e84a027.tar.gz
chromium_src-1cfb7420fb7ea2fa5a6360bbee5424918e84a027.tar.bz2
Complete initializing a GPU video decoder in a GLES2 context
In this patch a ggl::Context is connected to the GpuVideoDecoderHost in the renderer process. In the GPU process the GpuVideoDecoder is connected to a gles2::GLES2Decoder. These changes will be used in the future to switch context before issuing video decode commands. This is also needed by the GPU process to translate a client texture ID to a service texture ID in the GPU video decoder. BUG=53714 TEST=none Review URL: http://codereview.chromium.org/3266008 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@58518 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/common/gpu_video_common.h')
-rw-r--r--chrome/common/gpu_video_common.h19
1 files changed, 12 insertions, 7 deletions
diff --git a/chrome/common/gpu_video_common.h b/chrome/common/gpu_video_common.h
index f1d71dd..05923b6 100644
--- a/chrome/common/gpu_video_common.h
+++ b/chrome/common/gpu_video_common.h
@@ -21,12 +21,18 @@ class GpuVideoServiceInfoParam {
class GpuVideoDecoderInfoParam {
public:
- // global decoder id.
- int32 decoder_id_;
- // route id for GpuVideoDecoder on GPU process side for this channel.
- int32 decoder_route_id_;
- // route id for GpuVideoServiceHost on Render process side for this channel.
- int32 decoder_host_route_id_;
+ // Context ID of the GLES2 context what this decoder should assicate with.
+ int context_id;
+
+ // Global decoder id.
+ int32 decoder_id;
+
+ // Route id for GpuVideoDecoder on GPU process side for this channel.
+ int32 decoder_route_id;
+
+ // TODO(hclam): Merge this ID with |decoder_route_id_|.
+ // Route id for GpuVideoServiceHost on Render process side for this channel.
+ int32 decoder_host_route_id;
};
class GpuVideoDecoderInitParam {
@@ -169,4 +175,3 @@ struct ParamTraits<GpuVideoDecoderFormatChangeParam> {
};
#endif // CHROME_COMMON_GPU_VIDEO_COMMON_H_
-